@@ -7,6 +7,7 @@ from .config import LokiLoggerOptions
 from .flush_manager import AsyncFlushManager
 from .interceptors import (intercept_exceptions, intercept_logging,
                            intercept_print)
+from .post import post_to_loki
 from .safe_flush import safe_flush
 from .utils import now_ns, safe_json
 
@@ -33,10 +34,13 @@ class LokiLogger:
             return
         buffer_copy = self.log_buffer.copy()
         self.log_buffer.clear()
-        await self.flush_manager.send_logs(buffer_copy)
+        await self.send_logs(buffer_copy)
+
+    async def send_logs(self, logs: list[tuple[str, str]]) -> None:
+        await post_to_loki(logs, self.options)
 
     def flush_sync(self):
         try:
             asyncio.run(self.flush_logs())
         except RuntimeError:
-            pass
+            pass
\ No newline at end of file
